#-*- coding:utf-8 -*-

from django.utils.translation import ugettext_lazy as _

from nscms.base.simplenews.models import SimpleNewsModel

from ckeditor.fields import RichTextField
from taggit.managers import TaggableManager


class SimpleNews(SimpleNewsModel):
    content = RichTextField()
    tags = TaggableManager(blank=True)

    class Meta:
        ordering = ['-publish_date']
        verbose_name = _(u"Notícia")
        verbose_name_plural = _(u"Notícias")
        abstract = False

    def related_by_tags(self, count=10):
        qs = self.__class__.objects.published(order_by=None)
        qs = qs.filter(
            tags__pk__in=[i.pk for i in self.tags.all()]).exclude(pk=self.id)
        return qs[:count]



#-*- coding:utf-8 -*-

from django.db import models
from django.utils.translation import ugettext_lazy as _

from nscms.base.content.models import ContentModel, SimpleContentModel
from nscms.helpers.upload import UploadTo


class Section(SimpleContentModel):

    class Meta(SimpleContentModel.Meta): 
        abstract = False
        verbose_name = _(u'Section')
        verbose_name_plural = _(u'Sections')       
    
    
class Banner(ContentModel): 
    section = models.ForeignKey(
        "Section", verbose_name=_(u'Section'), blank=True, null=True)
    image = models.ImageField(_(u'Image'), upload_to=UploadTo('banners'))
    url = models.URLField(u"URL")




#-*- coding:utf-8 -*-

from nscms.base.content.models import SimpleContentModel, \
    PublisherModel

from django.db import models
from django.utils.translation import ugettext_lazy as _

from mptt.models import MPTTModel, TreeForeignKey
from ckeditor.fields import RichTextField


class SimplePageModel(MPTTModel, SimpleContentModel, PublisherModel):
    parent = TreeForeignKey(
        'self', verbose_name=_(u"Pai"), null=True, blank=True,
        related_name='children')
    content = RichTextField(verbose_name=_(u"Conteúdo"))
    redirect_to = TreeForeignKey(
        'self', verbose_name=_(u"Redirecionar para página"),
        null=True, blank=True,
        related_name='redirected_from')
    redirect_to_url = models.URLField(
        verbose_name=_(u"Redirecionar para esta URL"), blank=True)

    class Meta:
        abstract = True



 #!/usr/bin/env python
#-*- coding:utf-8 -*-

from django.http import HttpResponse

from .models import Subscription


def optin(request):
    if 'email' in request.GET:
        Subscription.objects.get_or_create(email=request.GET['email'])
    return HttpResponse()



import urlparse
import re

from django import forms
from django.db import models
from django.utils.translation import ugettext_lazy as _


def validate_youtube_url(value):
    '''El patron lo saque de
    http://stackoverflow.com/questions/2964678
    /jquery-youtube-url-validation-with-regex'''
    pattern = \
        r'^http(s)?:\/\/(?:www\.)?youtube.com\/watch\?(?=.*v=\w+)(?:\S+)?$'

    if value.startswith(('http://youtu.be/', 'https://youtu.be/')):
        if re.match(r'\w+', value[16:]) is None:
            raise forms.ValidationError(_('Not a valid Youtube URL'))
    elif re.match(pattern, value) is None:
        raise forms.ValidationError(_('Not a valid Youtube URL'))


class YoutubeUrl(unicode):

    @property
    def video_id(self):
        parsed_url = urlparse.urlparse(self)
        if parsed_url.query == '':
            return parsed_url.path
        return urlparse.parse_qs(parsed_url.query)['v'][0]

    @property
    def embed_url(self):
        return 'http://youtube.com/embed/%s/' % self.video_id

    @property
    def thumb(self):
        return "http://img.youtube.com/vi/%s/2.jpg" % self.video_id


class YoutubeUrlField(models.URLField):
    __metaclass__ = models.SubfieldBase

    def __init__(self, *args, **kwargs):
        super(YoutubeUrlField, self).__init__(*args, **kwargs)
        self.validators.append(validate_youtube_url)

    def to_python(self, value):
        url = super(YoutubeUrlField, self).to_python(value)
        return YoutubeUrl(url)

    def get_prep_value(self, value):
        return unicode(value)


try:
    from south.modelsinspector import add_introspection_rules
    add_introspection_rules(
        [],  ["^nscms\.db\.models\.youtube\.YoutubeUrlField"])
except ImportError:
    pass



#-*- coding:utf-8 -*-

from django.contrib import admin

from .models import Block


class BlockAdmin(admin.ModelAdmin):
    list_display = (
        "title", "slug", "published", "publish_date")
    search_fields = ("title", "slug", "content", )
    fieldsets = (
        (None, {'fields': ['title', 'content']}),
        (u"Publicação", {'fields': [
            'published', ('publish_date', 'expire_date')]}),
    )

admin.site.register(Block, BlockAdmin)



#!/usr/bin/env python
#-*- coding:utf-8 -*-

from django.conf.urls.defaults import patterns, include, url


urlpatterns = patterns('',
    url(r'^newsletter/',
        include('nscms.contrib.newsletter.urls', namespace="newsletter")),
)



#!/usr/bin/env python
#-*- coding:utf-8 -*-

from uuid import uuid4

from django.contrib.auth.models import User
from django.contrib.auth import login
from django.db import models


class UserProfileModel(models.Model):
    user = models.OneToOneField("auth.User")

    class Meta:
        abstract = True

    def auth_login(self, request,
            backend='django.contrib.auth.backends.ModelBackend'):
        self.user.backend = backend
        login(request, self.user)

    def save(self, *args, **kwargs):
        try:
            self.user
        except User.DoesNotExist:
            username = u"%s" % uuid4()
            username = username[:30]
            self.user = user = User.objects.create(username=username)
            user_set_password = getattr(self, '_user_set_password', None)
            if user_set_password is not None:
                user.set_password(user_set_password)
                user.email = self.email
                user.save()
            usercreated = True
        else:
            usercreated = False
        saved = super(UserProfileModel, self).save(*args, **kwargs)
        if usercreated:
            user.username = \
                u'%s-%d' % (self.__class__.__name__.lower(), self.id)
            user.email = self.email
            user.save()

        return saved



# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'SimplePage'
        db.create_table('simplepage_simplepage', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=120)),
            ('slug', self.gf('django_extensions.db.fields.AutoSlugField')(allow_duplicates=False, max_length=120, separator=u'-', blank=True, populate_from='title', overwrite=True)),
            ('created', self.gf('django.db.models.fields.DateTimeField')(default=datetime.datetime.now, blank=True)),
            ('modified', self.gf('django.db.models.fields.DateTimeField')(default=datetime.datetime.now, blank=True)),
            ('parent', self.gf('mptt.fields.TreeForeignKey')(blank=True, related_name='children', null=True, to=orm['simplepage.SimplePage'])),
            ('content', self.gf('ckeditor.fields.RichTextField')(blank=True)),
            ('redirect_to', self.gf('mptt.fields.TreeForeignKey')(blank=True, related_name='redirected_from', null=True, to=orm['simplepage.SimplePage'])),
            ('redirect_to_url', self.gf('django.db.models.fields.URLField')(max_length=200, blank=True)),
            ('lft', self.gf('django.db.models.fields.PositiveIntegerField')(db_index=True)),
            ('rght', self.gf('django.db.models.fields.PositiveIntegerField')(db_index=True)),
            ('tree_id', self.gf('django.db.models.fields.PositiveIntegerField')(db_index=True)),
            ('level', self.gf('django.db.models.fields.PositiveIntegerField')(db_index=True)),
        ))
        db.send_create_signal('simplepage', ['SimplePage'])


    def backwards(self, orm):
        # Deleting model 'SimplePage'
        db.delete_table('simplepage_simplepage')


    models = {
        'simplepage.simplepage': {
            'Meta': {'ordering': "['-created']", 'object_name': 'SimplePage'},
            'content': ('ckeditor.fields.RichTextField', [], {'blank': 'True'}),
            'created': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'level': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'lft': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'modified': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now', 'blank': 'True'}),
            'parent': ('mptt.fields.TreeForeignKey', [], {'blank': 'True', 'related_name': "'children'", 'null': 'True', 'to': "orm['simplepage.SimplePage']"}),
            'redirect_to': ('mptt.fields.TreeForeignKey', [], {'blank': 'True', 'related_name': "'redirected_from'", 'null': 'True', 'to': "orm['simplepage.SimplePage']"}),
            'redirect_to_url': ('django.db.models.fields.URLField', [], {'max_length': '200', 'blank': 'True'}),
            'rght': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'slug': ('django_extensions.db.fields.AutoSlugField', [], {'allow_duplicates': 'False', 'max_length': '120', 'separator': "u'-'", 'blank': 'True', 'populate_from': "'title'", 'overwrite': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '120'}),
            'tree_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'})
        }
    }

    complete_apps = ['simplepage']



#-*- coding:utf-8 -*-

from nscms.base.content.models import SimpleContentModel, \
    PublisherModel

from django.db import models
from django.utils.translation import ugettext_lazy as _

from mptt.models import MPTTModel, TreeForeignKey
from ckeditor.fields import RichTextField


class Block(SimpleContentModel, PublisherModel):
    content = RichTextField(verbose_name=_(u"Content"))

    class Meta:
        verbose_name = _(u"Block")
        verbose_name_plural = _(u"Block")



#-*- coding:utf-8 -*-

from django.utils.translation import ugettext_lazy as _

from nscms.base.simplepage.models import SimplePageModel


class SimplePage(SimplePageModel):

    class Meta:
        ordering = ['-created']
        verbose_name = _(u"Página")
        verbose_name_plural = _(u"Páginas")
        abstract = False

    def get_absolute_url(self):
        if self.redirect_to_url:
            return self.redirect_to_url

        if self.redirect_to:
            return self.redirect_to.get_absolute_url()

        parts = [self.slug]
        page = self
        while page.parent is not None:
            page = page.parent
            parts.insert(0, page.slug)
        return u"/%s/" % u"/".join(parts)
    get_absolute_url.short_description = u"URL"



from django import template

from classytags.core import Tag, Options
from classytags.arguments import Argument

from ..models import Block


register = template.Library()


class RenderBlock(Tag):
    name = 'render_block'
    options = Options(
        Argument('title'),
    )

    def render_tag(self, context, title):
        qs = Block.objects.published().filter(title=title)
        if qs.exists():
            block = qs[0]
        else:
            block = Block()
            block.title = title
            block.published = True
            block.save()
        return block.content


register.tag(RenderBlock)



#-*- coding:utf-8 -*-

from django.contrib.admin import site, ModelAdmin

from .models import SimpleNews


class SimpleNewsAdmin(ModelAdmin):
    date_hierarchy = "publish_date"
    search_fields = ("title", "description", "content",)
    list_filter = ("published", )
    list_display = (
        "title", "published", "publish_date",)
    fieldsets = (
        (None,
        {"fields": ("title", "tags", "image", "description", "content",)}),
        (u"Publicação",
            {"fields": ("published", "publish_date", "expire_date",)}),
        )


site.register(SimpleNews, SimpleNewsAdmin)



#!/usr/bin/env python
#-*- coding:utf-8 -*-

from django.core.urlresolvers import reverse
from django.test.client import Client
from django.test import TestCase

from .models import Subscription


class NewsletterTestCase(TestCase):

    def test_optin(self):
        email = u"user@domain.com"
        client = Client()
        url = reverse("newsletter:optin")
        response = client.get(url, {'email': email})
        self.assertEqual(response.status_code, 200)
        self.assertQuerysetEqual(
            Subscription.objects.all(), ['<Subscription: user@domain.com>'])



#!/usr/bin/env python
#-*- coding:utf-8 -*-

import datetime

from django.contrib import admin
from django.db import models
from django.utils.translation import ugettext_lazy as _

from django_extensions.db.fields import \
    AutoSlugField, CreationDateTimeField, ModificationDateTimeField


from .managers import BRPublisherModelManager


class BRCreationModificationModel(models.Model):

    data_criacao = CreationDateTimeField(_(u'Data de criação'))
    data_modificacao = ModificationDateTimeField(_(u'Data de modificação'))

    class Meta:
        abstract = True


class BRTitleSlugCreationModificationModel(BRCreationModificationModel):

    titulo = models.CharField(_(u'Título'), max_length=255)
    slug = AutoSlugField(
        _('slug'), populate_from='titulo', overwrite=True, max_length=255,
        editable=False)

    def __unicode__(self):
        return self.titulo

    class Admin(admin.ModelAdmin):
        list_display = ("titulo", "slug", "data_criacao", "data_modificacao", )
        list_filter = ("data_criacao", "data_modificacao", )

    class Meta:
        abstract = True
        ordering = ("titulo",  )


class BRPublisherModel(models.Model):
    _HELP_TEXT = _(u'Deixe em branco para publicação imediata.')
    publicado = models.BooleanField(_('Publicado'), default=False)
    data_publicacao = models.DateTimeField(
        blank=True,
        null=True,
        help_text=_HELP_TEXT,
        verbose_name=_(u'Data de publicação'))
    data_expiracao = models.DateTimeField(
        blank=True,
        null=True,
        help_text=_HELP_TEXT,
        verbose_name=_(u'Data de expiração'))

    objects = BRPublisherModelManager()

    class Meta:
        abstract = True
        ordering = ("-data_publicacao", "-publicado", )

    def is_publicado(self):
        now = datetime.datetime.now()
        return self.publicado and \
               self.data_publicacao <= now and \
               (self.data_expiracao is None or self.data_expiracao > now)

    def save(self, *args, **kwargs):
        if not self.data_publicacao:
            self.data_publicacao = datetime.datetime.now()
        return super(BRPublisherModel, self).save(*args, **kwargs)



# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'SimpleNews'
        db.create_table('simplenews_simplenews', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=120)),
            ('slug', self.gf('django_extensions.db.fields.AutoSlugField')(allow_duplicates=False, max_length=120, separator=u'-', blank=True, populate_from='title', overwrite=True)),
            ('description', self.gf('django.db.models.fields.TextField')(null=True, blank=True)),
            ('created', self.gf('django.db.models.fields.DateTimeField')(default=datetime.datetime.now, blank=True)),
            ('modified', self.gf('django.db.models.fields.DateTimeField')(default=datetime.datetime.now, blank=True)),
            ('published', self.gf('django.db.models.fields.BooleanField')(default=False)),
            ('publish_date', self.gf('django.db.models.fields.DateTimeField')(null=True, blank=True)),
            ('expire_date', self.gf('django.db.models.fields.DateTimeField')(null=True, blank=True)),
            ('image', self.gf('django.db.models.fields.files.ImageField')(max_length=255)),
            ('content', self.gf('ckeditor.fields.RichTextField')()),
        ))
        db.send_create_signal('simplenews', ['SimpleNews'])


    def backwards(self, orm):
        # Deleting model 'SimpleNews'
        db.delete_table('simplenews_simplenews')


    models = {
        'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'simplenews.simplenews': {
            'Meta': {'ordering': "['-publish_date']", 'object_name': 'SimpleNews'},
            'content': ('ckeditor.fields.RichTextField', [], {}),
            'created': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now', 'blank': 'True'}),
            'description': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'expire_date': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('django.db.models.fields.files.ImageField', [], {'max_length': '255'}),
            'modified': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now', 'blank': 'True'}),
            'publish_date': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'published': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'slug': ('django_extensions.db.fields.AutoSlugField', [], {'allow_duplicates': 'False', 'max_length': '120', 'separator': "u'-'", 'blank': 'True', 'populate_from': "'title'", 'overwrite': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '120'})
        },
        'taggit.tag': {
            'Meta': {'object_name': 'Tag'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'slug': ('django.db.models.fields.SlugField', [], {'unique': 'True', 'max_length': '100'})
        },
        'taggit.taggeditem': {
            'Meta': {'object_name': 'TaggedItem'},
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'taggit_taggeditem_tagged_items'", 'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'object_id': ('django.db.models.fields.IntegerField', [], {'db_index': 'True'}),
            'tag': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'taggit_taggeditem_items'", 'to': "orm['taggit.Tag']"})
        }
    }

    complete_apps = ['simplenews']


#!/usr/bin/env python
#-*- coding:utf-8 -*-

from datetime import datetime
import os

from django.template.defaultfilters import slugify


def slugify_filename(filename):
    name, ext = os.path.splitext(filename)
    return slugify(name) + ext


class UploadTo(object):
    def __init__(self, base="portal", strftime="%Y/%m", instance_field="title",
        max_length=None):
        self.base = base
        self.strftime = strftime
        self.instance_field = instance_field
        self.max_length = max_length

    def __call__(self, instance, filename):
        Model = type(instance)
        max_length = self.max_length
        for field in Model._meta.fields:
            if field.name == self.instance_field:
                max_length = field.max_length
        name, ext = os.path.splitext(os.path.basename(filename))
        if callable(self.instance_field):
            value = self.instance_field(instance)
        else:
            value = getattr(instance, self.instance_field)

        filename = slugify_filename("%s%s" % (value[:max_length], ext))
        return os.path.join(
            self.base, datetime.now().strftime(self.strftime), filename)



#!/usr/bin/env python
#-*- coding:utf-8 -*-

from django.contrib import admin

from .models import News


class NewsAdmin(admin.ModelAdmin):
    fields = ("title", "body", ("published", "publish_date", ))


admin.site.register(News, NewsAdmin)



#-*- coding:utf-8 -*-

from django.contrib.admin import ModelAdmin, site

from .models import Section, Banner


class SectionAdmin(ModelAdmin):
    pass


site.register(Section, SectionAdmin)


class BannerAdmin(ModelAdmin):
    fieldsets = (
        (None, {'fields': [
            'section', 'title', 'image', 'url']}),
        (u"Publicação", {'fields': [
            'published', ('publish_date', 'expire_date', )]}),
    )
    list_display = ("title", "url", "section", "published", "publish_date", )
    list_filter = ("section", "published", "publish_date", )


site.register(Banner, BannerAdmin)



#!/usr/bin/env python
#-*- coding:utf-8 -*-

import datetime

from django.db.models import Q
from django.db import models


# Thanks to http://djangosnippets.org/snippets/562/


class BRPublisherModelQuerySet(models.query.QuerySet):

    def publicados(self):
        now = datetime.datetime.now()
        return self.filter(
            Q(publicado=True),
            Q(data_publicacao__lte=now),
            Q(data_expiracao__isnull=True) | Q(data_expiracao__gt=now))


class BRPublisherModelManager(models.Manager):
    queryset_class = BRPublisherModelQuerySet

    def get_query_set(self):
#        model = models.get_model('news', 'BRPublisherModelItem')
#        if self.model._meta.abstract:
#            return models.query.QuerySet(self.model)
#        else:
        return self.queryset_class(self.model)

    def publicados(self):
        return self.get_query_set().publicados()

#    def __getattr__(self, attr, *args):
#        if attr in ("publicados", ):
#            return getattr(self.get_query_set(), attr, *args)
#        else:
#            return super(BRPublisherModelManager, self).__getattr__(
#                attr, *args)
#            return getattr(self.__class__, attr, *args)



#!/usr/bin/env python
#-*- coding:utf-8 -*-

from django.conf.urls.defaults import patterns, url


urlpatterns = patterns('nscms.contrib.newsletter.views',
    url(r'^optin/$', 'optin', name="optin"),
)



#-*- coding:utf-8 -*-

from django.shortcuts import render, redirect, get_object_or_404

from nscms.simplepage.models import SimplePage


def page(request, url, template_name=u"site/pages/page.html", context={}):
    parts = url.split("/")
    qs = SimplePage.objects.filter(published=True)
    root = parts[0]
    nodes = parts[1:]
    current = get_object_or_404(qs, slug=root, parent__isnull=True)
    for slug in nodes:
        current = get_object_or_404(qs, slug=slug, parent=current)
    page = current
    if page.redirect_to_url:
        return redirect(page.redirect_to_url)

    if page.redirect_to is not None:
        return redirect(page.redirect_to.get_absolute_url())

    context.update({
        'page': page,
    })
    return render(request, template_name, context)



#-*- coding:utf-8 -*-

from nscms.base.content.models import CreationModificationModel

from django.utils.translation import ugettext_lazy as _
from django.db import models

from django_extensions.db.fields import UUIDField


class Subscription(CreationModificationModel):

    email = models.EmailField(unique=True)
    uuid = UUIDField()

    class Meta:
        verbose_name = _(u"Inscrição")
        verbose_name_plural = _(u"Inscrições")
        ordering = ("-created", )

    def __unicode__(self):
        return self.email

    def save(self, *args, **kwargs):
        self.email = self.email.lower()
        return super(Subscription, self).save(*args, **kwargs)



#!/usr/bin/env python
#-*- coding:utf-8 -*-

from django.db import models

from nscms.base.content.models import ContentModel


class News(ContentModel):
    body = models.TextField()

    class Meta(ContentModel.Meta):
        abstract = False
        verbose_name = u"Notícia"
        verbose_name_plural = u"Notícias"



#-*- coding:utf-8 -*-

from django.contrib import admin

from feincms.admin import tree_editor

from nscms.simplepage.models import SimplePage


class SimplePageAdmin(tree_editor.TreeEditor):
    list_display = (
        "title", "slug", "get_absolute_url", "published", "redirect_to",
        "redirect_to_url", )
    search_fields = ("title", "slug", "content", )
    fieldsets = (
        (None, {'fields': ['parent', 'title', 'content']}),
        (u"Publicação", {'fields': [
            'published', ('publish_date', 'expire_date')]}),
        (u"Redirecionar", {
            'description': "Caso uma página não possua conteúdo é possível " \
            "definir um redirecionamento. A prioridade de redirecionamento " \
            "segue a ordem abaixo.",
            'fields': ['redirect_to', "redirect_to_url"],
            'classes': ['grp-collapse grp-closed']}),
    )

admin.site.register(SimplePage, SimplePageAdmin)



#-*- coding:utf-8 -*-

from django.conf import settings
from django.utils.translation import ugettext_lazy as _
from django.db import models

from nscms.base.content.models import ContentModel


SIMPLENEWS_IMAGE_UPLOAD_TO = \
    getattr(settings, "SIMPLENEWS_IMAGE_UPLOAD_TO", "simplenews")


class SimpleNewsModel(ContentModel):
    image = models.ImageField(
        upload_to=SIMPLENEWS_IMAGE_UPLOAD_TO, max_length=255, blank=True)

    class Meta:
        ordering = ['-publish_date']
        verbose_name = _(u"Notícia")
        verbose_name_plural = _(u"Notícias")
        abstract = True



#-*- coding:utf-8 -*-

from django.forms import *

from taggit.models import Tag
from taggit.forms import TagField
from taggit.utils import edit_string_for_tags, parse_tags


class TagSelectMultiple(CheckboxSelectMultiple):
    def render(self, name, value, attrs=None):
        choices = [(i.name, i.name) for i in Tag.objects.all().order_by("name")]
        if value and value is not None and not isinstance(value, (basestring, list)):
            value = edit_string_for_tags([o.tag for o in value.select_related("tag")])
            value = parse_tags(value)
        return super(TagSelectMultiple, self).render(name, value, attrs, choices=choices)


class CheckboxTagField(TagField):
    widget = TagSelectMultiple

    def clean(self, value):
        value = ','.join(["\"%s\"" % i for i in value])
        return super(CheckboxTagField, self).clean(value)



#-*- coding:utf-8 -*-

from django.contrib import admin
from django.db.models import Q
from django.db import models
from django.utils.translation import ugettext_lazy as _

from ckeditor.fields import RichTextField
from django_extensions.db.fields import CreationDateTimeField,\
    ModificationDateTimeField, AutoSlugField

import datetime


class PublisherModelManager(models.Manager):
    """ PublisherModelManager
    Manager to return instances of ActivatorModel:
    SomeModel.objects.published() / .expired()
    """
    def published(self, order_by=None):
        """ Returns published instances of PublisherModel:
            SomeModel.objects.published() """
        now = datetime.datetime.now()
        qset = super(PublisherModelManager, self).filter(
            Q(published=True),
            Q(publish_date__lte=now),
            Q(expire_date__isnull=True) | Q(expire_date__gt=now)
        )
        if order_by is not None:
            qset = qset.order_by(order_by)
        return qset

    def unpublished(self):
        """ Returns published instances of PublisherModel:
            SomeModel.objects.published() """
        now = datetime.datetime.now()
        return super(PublisherModelManager, self).get_query_set().filter(
            published=True,
            publish_date__gt=now
        ).order_by("publish_date")

    def expired(self):
        """ Returns expired instances of PublisherModel:
            SomeModel.objects.expired() """
        now = datetime.datetime.now()
        return super(PublisherModelManager, self).get_query_set().filter(
            expire_date__lt=now
        ).order_by("publish_date")


class SimpleContentModel(models.Model):
    title = models.CharField(
        _('title'), max_length=255)
    slug = AutoSlugField(
        _('slug'), populate_from='title',
        overwrite=True, max_length=255,
        editable=False)
    created = CreationDateTimeField(_('created'), db_index=True)
    modified = ModificationDateTimeField(_('modified'), db_index=True)

    def __unicode__(self):
        return self.title

    class Meta:
        ordering = ("title", )
        abstract = True


class PersonModel(models.Model):
    name = models.CharField(_('name'), max_length=255)
    slug = AutoSlugField(
        _('slug'), populate_from='name', overwrite=True,
        max_length=255, editable=False)
    created = CreationDateTimeField(_('created'))
    modified = ModificationDateTimeField(_('modified'))

    def __unicode__(self):
        return self.name

    class Meta:
        ordering = ("name", )
        abstract = True


class CreationModificationModel(models.Model):
    created = CreationDateTimeField(_('created'), db_index=True)
    modified = ModificationDateTimeField(_('modified'), db_index=True)

    class Meta:
        abstract = True
        ordering = ("-created", "-modified", )


DateContentModel = CreationModificationModel


class PublisherModel(models.Model):
    """ PublisherModel
    An abstract base class model that provides publish and expired fields.
    """
    objects = PublisherModelManager()

    published = models.BooleanField(
        _('published'),
        default=False,
        db_index=True)

    publish_date = models.DateTimeField(
        verbose_name=_('publish date'),
        help_text=_('keep empty for an immediate publication'),
        blank=True,
        db_index=True,
        null=True)

    expire_date = models.DateTimeField(
        verbose_name=_('expire date'),
        help_text=_('keep empty for indefinite expiration'),
        blank=True,
        null=True,
        db_index=True)

    class Meta:
        abstract = True
        ordering = ("-publish_date", "-published", )

    def is_published(self):
        now = datetime.datetime.now()
        return self.published and \
            self.publish_date <= now and \
            (self.expire_date is None or self.expire_date > now)

    def save(self, *args, **kwargs):
        if not self.publish_date:
            self.publish_date = datetime.datetime.now()
        super(PublisherModel, self).save(*args, **kwargs)


ADMIN_FIELDSET_TITLE = (None, {"fields": ("title", "description", )})


ADMIN_FIELDSET_PUBLISHING = (
    _(u"Publicação"),
    {"fields": ("published", "publish_date", "expire_date", )})


class ContentModel(PublisherModel):
    title = models.CharField(
        _('title'),
        max_length=255)

    slug = AutoSlugField(
        verbose_name=_('slug'),
        populate_from='title',
        overwrite=True,
        editable=False,
        max_length=255,
        db_index=True)

    description = models.TextField(_('description'), blank=True, null=True)

    created = CreationDateTimeField(
        verbose_name=_('created'),
        db_index=True)

    modified = ModificationDateTimeField(
        _('modified'),
        db_index=True)

    ADMIN_FIELDSET_TITLE = ADMIN_FIELDSET_TITLE
    ADMIN_FIELDSET_PUBLISHING = ADMIN_FIELDSET_PUBLISHING

    class Admin(admin.ModelAdmin):
        date_hierarchy = 'publish_date'
        fieldsets = (
            ADMIN_FIELDSET_TITLE,
            ADMIN_FIELDSET_PUBLISHING,
        )
        list_display = ("title", "publish_date", "published", )
        list_filter = ("published", )
        search_fields = ("title", "description", )

    class Meta(PublisherModel.Meta):
        abstract = True

    def __unicode__(self):
        return self.title


class TextContentModel(ContentModel):
    body = RichTextField(verbose_name=_(u"Corpo"))

    class Admin(ContentModel.Admin):
        fieldsets = (
            (None, {"fields": ("title", "description", "body", )}),
            ADMIN_FIELDSET_PUBLISHING,
        )

    class Meta(ContentModel.Meta):
        abstract = True


class PTBRSimpleContentModel(models.Model):
    title = models.CharField(_(u'Título'), max_length=255)
    slug = AutoSlugField(
        _('slug'), populate_from='titulo',
        overwrite=True, max_length=255, editable=False)

    created_at = CreationDateTimeField(_(u'Criado em'))
    changed_at = ModificationDateTimeField(_(u'Modificado em'))

    def __unicode__(self):
        return self.title

    class Meta:
        abstract = True
        ordering = ("titulo", )


try:
    from south.modelsinspector import add_introspection_rules
except ImportError:
    pass
else:
    add_introspection_rules([], ["^ckeditor\.fields\.RichTextField"])



# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):

        # Changing field 'SimplePage.content'
        db.alter_column('simplepage_simplepage', 'content', self.gf('ckeditor.fields.RichTextField')())

    def backwards(self, orm):

        # Changing field 'SimplePage.content'
        db.alter_column('simplepage_simplepage', 'content', self.gf('ckeditor.fields.RichTextField')())

    models = {
        'simplepage.simplepage': {
            'Meta': {'ordering': "['-created']", 'object_name': 'SimplePage'},
            'content': ('ckeditor.fields.RichTextField', [], {}),
            'created': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now', 'blank': 'True'}),
            'expire_date': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'level': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'lft': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'modified': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now', 'blank': 'True'}),
            'parent': ('mptt.fields.TreeForeignKey', [], {'blank': 'True', 'related_name': "'children'", 'null': 'True', 'to': "orm['simplepage.SimplePage']"}),
            'publish_date': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'published': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'redirect_to': ('mptt.fields.TreeForeignKey', [], {'blank': 'True', 'related_name': "'redirected_from'", 'null': 'True', 'to': "orm['simplepage.SimplePage']"}),
            'redirect_to_url': ('django.db.models.fields.URLField', [], {'max_length': '200', 'blank': 'True'}),
            'rght': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'slug': ('django_extensions.db.fields.AutoSlugField', [], {'allow_duplicates': 'False', 'max_length': '120', 'separator': "u'-'", 'blank': 'True', 'populate_from': "'title'", 'overwrite': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '120'}),
            'tree_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'})
        }
    }

    complete_apps = ['simplepage']
